==> prestashop_1.3.0.1.zip: prestashop/install/langs/us.php <==
<?php

$_LANG['A mail has been sended!'] = 'A mail has been sent';
$_LANG['An error occured while sending mail, please verify your parameters.'] = 'An error occurred while sending mail. Please verify your parameters.';
$_LANG['And now, discover your new store and Back Office'] = 'Take me to my new Front Office (online store) or Back Office (admin tool)';
$_LANG['Before continuing, you have to backup your data. Please backup the database and backup the files of the application.'] = 'Before continuing, you have to backup your data. Please backup the database and backup the application files.';
$_LANG['By default, the PHP \'mail()\' function is used'] = 'By default, the PHP \'mail()\' function is used. For more functionality, manual SMTP configuration is recommended.';
$_LANG['Can\'t find the sql upgrade files. Please verify that the /install/sql/upgrade folder is not empty)'] = 'Can\'t find the SQL upgrade files. Please verify that the /install/sql/upgrade folder is not empty.';
$_LANG['Can\'t create settings file, if /config/settings.inc.php exists, please give the public write permissions to this file, else please create a file named settings.inc.php in config directory.'] = 'Can\'t create settings file, if /config/settings.inc.php exists, please give the public write permissions to this file, else please create a file named settings.inc.php in config directory.';
$_LANG['Congratulation, your online shop is now ready!'] = 'Congratulations, your online store is now ready to open!';
$_LANG['Create new files and folders allowed'] = 'Allowed to create new files and folders';
$_LANG['Database Server is not found. Please verify the login, password and server fields.'] = 'Database server was not found. Please verify the login, password, and database server name fields.';
$_LANG['Database connection is available!'] = 'Database is connected.';
$_LANG['Database is created!'] = 'Database has been created.';
$_LANG['Enter the url to enter into the Back Office'] = 'Add the directory name of the Back Office to your shop\'s URL';
$_LANG['Error while loading sql upgrade file.'] = 'Error while loading SQL upgrade file';
$_LANG['Fields are different!'] = 'Fields don\'t match';
$_LANG['File upload allowed'] = 'Allowed to upload files';
$_LANG['Full mode: Install the main modules and add sample products'] = 'Full mode: Install all basic modules and add sample products';
$_LANG['GD Library installed'] = 'GD Library is installed';
$_LANG['GZIP compression is on (recommended)'] = 'GZIP compression is on (recommended)';
$_LANG['Here are your shop information. You can modify them once logged in.'] = 'Below are your shop details. You can modify these after logging in to the Back Offce.';
$_LANG['Impossible the access the a MySQL content file.'] = 'Unable to access the MySQL content file.';
$_LANG['Impossible the read the content of a MySQL content file.'] = 'Unable to read the content an MySQL content file.';
$_LANG['Impossible to send the mail!'] = 'Unable to send the e-mail.';
$_LANG['Impossible to upload the file!'] = 'Unable to upload file.';
$_LANG['Installation : complete install of the PrestaShop Solution'] = 'Installation: Full installation of the PrestaShop™ e-Commerce Solution';
$_LANG['Merchant info'] = 'Merchant admin info';
$_LANG['Your Back Office'] = 'Your Back Office';
$_LANG['Your shop'] = 'Your Front Office';
$_LANG['No upgrade is possible.'] = 'No update available';
$_LANG['One or more errors have occurred...'] = 'One or more errors have occurred';
$_LANG['Open external URLs allowed'] = 'Allowed to open external URLs';
$_LANG['PHP parameters:'] = 'PHP settings (modify via your PHP admin software):';
$_LANG['PHP register global option is off (recommended)'] = 'PHP register global option is off (recommended)';
$_LANG['Password:'] = 'Password:';
$_LANG['Please set a SMTP login'] = 'Please enter the SMTP login';
$_LANG['Please set a SMTP password'] = 'Please enter the SMTP password';
$_LANG['Please set a SMTP server name'] = 'Please enter the SMTP server name';
$_LANG['Please set a database login'] = 'Please enter the database login';
$_LANG['Please set a database name'] = 'Please enter the database name';
$_LANG['Please set a database server name'] = 'Please enter the database server name';
$_LANG['PrestaShop '.INSTALL_VERSION.' Installer'] = 'PrestaShop™ v'.INSTALL_VERSION.' Installer';
$_LANG['PrestaShop is ready!'] = 'Congratulations!';
$_LANG['Required set-up. Please make sure the following checklist items are true.'] = 'The following settings are required. Please make sure the following checklist items are true.';
$_LANG['SMTP connection is available!'] = 'SMTP connection successful';
$_LANG['SMTP connection is unavailable'] = 'SMTP connection not successful';
$_LANG['Select the different languages available for your shop'] = 'Add languages available to shop visitors';
$_LANG['Send me a test email!'] = 'Send me a test e-mail';
$_LANG['Server:'] = 'Database server name:';
$_LANG['Shop\'s default language'] = 'Your shop\'s default language';
$_LANG['Shop\'s languages'] = 'Shop languages';
$_LANG['Simple mode: Dont\' install any module'] = 'Simple mode: Don\'t install modules or sample data';
$_LANG['Surname'] = 'Last Name';
$_LANG['Tables prefix:'] = 'PrestaShop database tables prefix:';
$_LANG['Test message - Prestashop'] = 'Test message from PrestaShop';
$_LANG['The config/settings.inc.php file was not found. Did you delete or rename this file?'] = 'The config/settings.inc.php file was not found. The file may have been deleted or renamed.';
$_LANG['The password is incorrect (alphanumeric string at least 8 characters).'] = 'Password is incorrect (alphanumeric string at least 8 characters).';
$_LANG['This PrestaShop database already exists. Please revalidate your authentication informations to the database.'] = 'This PrestaShop database already exists. Please re-enter your database login information.';
$_LANG['This email adress is wrong!'] = 'Invalid e-mail address';
$_LANG['This installer is too old.'] = 'This installer is for an older version of PrestaShop';
$_LANG['This is a test message, your server is now available to send mail'] = 'This is a test message. Your server is now set up to send e-mail.';
$_LANG['This is not a valid file name.'] = 'Invalid file name';
$_LANG['This is not a valid image file.'] = 'Invalid image file';
$_LANG['Too long!'] = 'Too long';
$_LANG['Upgrade: get the latest stable version!'] = 'Update: Get the latest stable version';
$_LANG['Verify system compatibility'] = 'System compatibility';
$_LANG['WARNING: For more security, you must delete the \'install\' folder.'] = 'WARNING! For security reasons, you must now delete the \'install\' folder located on your hosting server.';
$_LANG['Warning: a manual backup is HIGHLY recommended before continuing!'] = 'WARNING! A manual backup is HIGHLY recommended before continuing.';
$_LANG['Welcome'] = 'Welcome!';
$_LANG['Welcome to the PrestaShop '.INSTALL_VERSION.' Installer.'] = 'Welcome to the PrestaShop™ v'.INSTALL_VERSION.' Installer wizard.';
$_LANG['When your files and database are saving in an other support, please certify that your shop is really backed up.'] = 'Once your application files and database have been saved, we ask you to certify it. By doing so, you assume all responsability for any data loss due to an update of PrestaShop software.';
$_LANG['Write permissions on folders (and subfolders):'] = 'Write permissions on folders and subfolders/recursively:';
$_LANG['Write permissions on folders:'] = 'Write permissions on folders (do not apply recursively/to subfolders):';
$_LANG['You already have the '.INSTALL_VERSION.' version.'] = 'Version v'.INSTALL_VERSION.' is already installed.';
$_LANG['You\'ve just installed and configured PrestaShop as your online shop solution. We wish you all the best with the success of your online shop.'] = 'You have just installed and configured PrestaShop to be your online shop solution. We wish you unqualified success!';
$_LANG['You\'ve just updated and configured PrestaShop as your online shop solution. We wish you all the best with the success of your online shop.'] = 'You have just updated and configured PrestaShop to be your online shop solution. May it be a success!';
$_LANG['Your installation is finished!'] = 'Installation is complete!';
$_LANG['Your update is finished!'] = 'Update is finished!';
$_LANG['recommended dimensions: 230px X 75px'] = 'Recommended size: 230x75 px';
$_LANG['view the log'] = 'View the log';
$_LANG['the already installed version detected is too old, no more update available'] = 'The existing installation of PrestaShop is outdated. No updates are available';
$_LANG['Reunion'] = 'Réunion';
$_LANG['Saint Barthelemy'] = 'Saint Barthélemy';
$_LANG['Sao Tome and Principe'] = 'São Tomé and Príncipe';
$_LANG['Aland Islands'] = 'Åland Islands';

?>

==> prestashop_1.3.2.3.zip: prestashop/install/langs/us.php <==
<?php

$_LANG['A mail has been sended!'] = 'A mail has been sent';
$_LANG['An error occured while sending mail, please verify your parameters.'] = 'An error occurred while sending mail. Please verify your parameters.';
$_LANG['And now, discover your new store and Back Office'] = 'Take me to my new Front Office (online store) or Back Office (admin tool)';
$_LANG['Before continuing, you have to backup your data. Please backup the database and backup the files of the application.'] = 'Before continuing, you have to backup your data. Please backup the database and backup the application files.';
$_LANG['By default, the PHP \'mail()\' function is used'] = 'By default, the PHP \'mail()\' function is used. For more functionality, manual SMTP configuration is recommended.';
$_LANG['Can\'t find the sql upgrade files. Please verify that the /install/sql/upgrade folder is not empty)'] = 'Can\'t find the SQL upgrade files. Please verify that the /install/sql/upgrade folder is not empty.';
$_LANG['Can\'t create settings file, if /config/settings.inc.php exists, please give the public write permissions to this file, else please create a file named settings.inc.php in config directory.'] = 'Can\'t create settings file, if /config/settings.inc.php exists, please give the public write permissions to this file, else please create a file named settings.inc.php in config directory.';
$_LANG['Congratulation, your online shop is now ready!'] = 'Congratulations, your online store is now ready to open!';
$_LANG['Create new files and folders allowed'] = 'Allowed to create new files and folders';
$_LANG['Database Server is not found. Please verify the login, password and server fields.'] = 'Database server was not found. Please verify the login, password, and database server name fields.';
$_LANG['Database connection is available!'] = 'Database is connected.';
$_LANG['Database is created!'] = 'Database has been created.';
$_LANG['Enter the url to enter into the Back Office'] = 'Add the directory name of the Back Office to your shop\'s URL';
$_LANG['Error while loading sql upgrade file.'] = 'Error while loading SQL upgrade file';
$_LANG['Fields are different!'] = 'Fields don\'t match';
$_LANG['File upload allowed'] = 'Allowed to upload files';
$_LANG['Full mode: Install the main modules and add sample products'] = 'Full mode: Install all basic modules and add sample products';
$_LANG['GD Library installed'] = 'GD Library is installed';
$_LANG['GZIP compression is on (recommended)'] = 'GZIP compression is on (recommended)';
$_LANG['Here are your shop information. You can modify them once logged in.'] = 'Below are your shop details. You can modify these after logging in to the Back Offce.';
$_LANG['Impossible the access the a MySQL content file.'] = 'Unable to access the MySQL content file.';
$_LANG['Impossible to read the content of a MySQL content file.'] = 'Unable to read the content an MySQL content file.';
$_LANG['Impossible to send the mail!'] = 'Unable to send the e-mail.';
$_LANG['Impossible to upload the file!'] = 'Unable to upload file.';
$_LANG['Installation : complete install of the PrestaShop Solution'] = 'Installation: Full installation of the PrestaShop™ e-Commerce Solution';
$_LANG['Merchant info'] = 'Merchant admin info';
$_LANG['Your Back Office'] = 'Your Back Office';
$_LANG['Your shop'] = 'Your Front Office';
$_LANG['No upgrade is possible.'] = 'No update available';
$_LANG['One or more errors have occurred...'] = 'One or more errors have occurred';
$_LANG['Open external URLs allowed'] = 'Allowed to open external URLs';
$_LANG['PHP parameters:'] = 'PHP settings (modify via your PHP admin software):';
$_LANG['PHP register global option is off (recommended)'] = 'PHP register global option is off (recommended)';
$_LANG['Password:'] = 'Password:';
$_LANG['Please set a SMTP login'] = 'Please enter the SMTP login';
$_LANG['Please set a SMTP password'] = 'Please enter the SMTP password';
$_LANG['Please set a SMTP server name'] = 'Please enter the SMTP server name';
$_LANG['Please set a database login'] = 'Please enter the database login';
$_LANG['Please set a database name'] = 'Please enter the database name';
$_LANG['Please set a database server name'] = 'Please enter the database server name';
$_LANG['PrestaShop '.INSTALL_VERSION.' Installer'] = 'PrestaShop™ v'.INSTALL_VERSION.' Installer';
$_LANG['PrestaShop is ready!'] = 'Congratulations!';
$_LANG['Required set-up. Please make sure the following checklist items are true.'] = 'The following settings are required. Please make sure the following checklist items are true.';
$_LANG['SMTP connection is available!'] = 'SMTP connection successful';
$_LANG['SMTP connection is unavailable'] = 'SMTP connection not successful';
$_LANG['Select the different languages available for your shop'] = 'Add languages available to shop visitors';
$_LANG['Send me a test email!'] = 'Send me a test e-mail';
$_LANG['Server:'] = 'Database server name:';
$_LANG['Shop\'s default language'] = 'Your shop\'s default language';
$_LANG['Shop\'s languages'] = 'Shop languages';
$_LANG['Simple mode: Dont\' install any module'] = 'Simple mode: Don\'t install modules or sample data';
$_LANG['Surname'] = 'Last Name';
$_LANG['Tables prefix:'] = 'PrestaShop database tables prefix:';
$_LANG['Test message - Prestashop'] = 'Test message from PrestaShop';
$_LANG['The config/settings.inc.php file was not found. Did you delete or rename this file?'] = 'The config/settings.inc.php file was not found. The file may have been deleted or renamed.';
$_LANG['The password is incorrect (alphanumeric string at least 8 characters).'] = 'Password is incorrect (alphanumeric string at least 8 characters).';
$_LANG['This PrestaShop database already exists. Please revalidate your authentication informations to the database.'] = 'This PrestaShop database already exists. Please re-enter your database login information.';
$_LANG['This email adress is wrong!'] = 'Invalid e-mail address';
$_LANG['This installer is too old.'] = 'This installer is for an older version of PrestaShop';
$_LANG['This is a test message, your server is now available to send mail'] = 'This is a test message. Your server is now set up to send e-mail.';
$_LANG['This is not a valid file name.'] = 'Invalid file name';
$_LANG['This is not a valid image file.'] = 'Invalid image file';
$_LANG['Too long!'] = 'Too long';
$_LANG['Upgrade: get the latest stable version!'] = 'Update: Get the latest stable version';
$_LANG['Verify system compatibility'] = 'System compatibility';
$_LANG['WARNING: For more security, you must delete the \'install\' folder.'] = 'WARNING! For security reasons, you must now delete the \'install\' folder located on your hosting server.';
$_LANG['Warning: a manual backup is HIGHLY recommended before continuing!'] = 'WARNING! A manual backup is HIGHLY recommended before continuing.';
$_LANG['Welcome'] = 'Welcome!';
$_LANG['Welcome to the PrestaShop '.INSTALL_VERSION.' Installer.'] = 'Welcome to the PrestaShop™ v'.INSTALL_VERSION.' Installer wizard.';
$_LANG['When your files and database are saving in an other support, please certify that your shop is really backed up.'] = 'Once your application files and database have been saved, we ask you to certify it. By doing so, you assume all responsability for any data loss due to an update of PrestaShop software.';
$_LANG['Write permissions on folders (and subfolders):'] = 'Write permissions on folders and subfolders/recursively:';
$_LANG['Write permissions on folders:'] = 'Write permissions on folders (do not apply recursively/to subfolders):';
$_LANG['You already have the '.INSTALL_VERSION.' version.'] = 'Version v'.INSTALL_VERSION.' is already installed.';
$_LANG['You\'ve just installed and configured PrestaShop as your online shop solution. We wish you all the best with the success of your online shop.'] = 'You have just installed and configured PrestaShop to be your online shop solution. We wish you unqualified success!';
$_LANG['You\'ve just updated and configured PrestaShop as your online shop solution. We wish you all the best with the success of your online shop.'] = 'You have just updated and configured PrestaShop to be your online shop solution. May it be a success!';
$_LANG['Your installation is finished!'] = 'Installation is complete!';
$_LANG['Your update is finished!'] = 'Update is finished!';
$_LANG['recommended dimensions: 230px X 75px'] = 'Recommended size: 230x75 px';
$_LANG['view the log'] = 'View the log';
$_LANG['the already installed version detected is too old, no more update available'] = 'The existing installation of PrestaShop is outdated. No updates are available';
$_LANG['Reunion'] = 'Réunion';
$_LANG['Saint Barthelemy'] = 'Saint Barthélemy';
$_LANG['Sao Tome and Principe'] = 'São Tomé and Príncipe';
$_LANG['Aland Islands'] = 'Åland Islands';

?>
